/*
  Programma:max30100_minimal_lcd.ino
  Il programma misura i battiti cardiaci e il
  valore dell'ossigenazione riportando i dati
  sul monitor seriale o si display LCD
   
  Creato il 11/5/2019 da Adriano Gandolfo

  Sito web https://www.adrirobot.it
  Blog https://it.emcelettronica.com/author/adrirobot
  Pagina Facebook https://www.facebook.com/Adrirobot-318949048122955
  Istagram https://www.instagram.com/adrirobot/
  This example code is in the public domain.
*/

#include <Wire.h>
#include "MAX30100_PulseOximeter.h"
#include <LiquidCrystal_I2C.h>

// Set the LCD address to 0x27 for a 16 chars and 2 line display
LiquidCrystal_I2C lcd(0x27, 16, 2);

#define REPORTING_PERIOD_MS     1000

// PulseOximeter is the higher level interface to the sensor
// it offers:
//  * beat detection reporting
//  * heart rate calculation
//  * SpO2 (oxidation level) calculation
PulseOximeter pox;

uint32_t tsLastReport = 0;

// Callback (registered below) fired when a pulse is detected
void onBeatDetected()
{
  Serial.println("Beat!");
}

void setup()
{
  Serial.begin(115200);
  lcd.begin(); //Init with pin default ESP8266 or ARDUINO
  lcd.backlight();
  Serial.print("Initializing pulse oximeter..");
  lcd.setCursor(0, 0);
    lcd.print("Batt: "); lcd.print ("     "); lcd.print(" bpm");
    lcd.setCursor(0, 1);
    lcd.print("Oss.: "); lcd.print ("     "); lcd.print(" %");

  // Initialize the PulseOximeter instance
  // Failures are generally due to an improper I2C wiring, missing power supply
  // or wrong target chip
  if (!pox.begin()) {
    Serial.println("FAILED");
    for (;;);
  } else {
    Serial.println("SUCCESS");
  }

  // The default current for the IR LED is 50mA and it could be changed
  //   by uncommenting the following line. Check MAX30100_Registers.h for all the
  //   available options.
  // pox.setIRLedCurrent(MAX30100_LED_CURR_7_6MA);

  // Register a callback for the beat detection
  pox.setOnBeatDetectedCallback(onBeatDetected);
}

void loop()
{
  // Make sure to call update as fast as possible
  pox.update();

  // Asynchronously dump heart rate and oxidation levels to the serial
  // For both, a value of 0 means "invalid"
  if (millis() - tsLastReport > REPORTING_PERIOD_MS) {
    Serial.print("Heart rate:");
    Serial.print(pox.getHeartRate());
    Serial.print("bpm / SpO2:");
    Serial.print(pox.getSpO2());
    Serial.println("%");
 
    lcd.setCursor(6, 0);
    lcd.print ("     ");
    lcd.setCursor(6, 0);
    lcd.print(pox.getHeartRate());
    lcd.setCursor(6, 1);
    lcd.print ("     ");
    lcd.setCursor(6, 1);
    lcd.print(pox.getSpO2());

    tsLastReport = millis();
  }
}
